#!/bin/bash

OPEN_CONNECTIONS="$(su postgres -c "psql -t -c 'SELECT COUNT(*) FROM pg_stat_activity'" | awk 'NR == 1 { print $1 }')"
MAX_CONNECTIONS="$(su postgres -c "psql -t -c 'SHOW max_connections'" | awk 'NR == 1 { print $1 }')"

while [[ $# -gt 1 ]]; do
	key="$1"
	case $key in
	        -w|--warning)
		WARNING_THRESHOLD="$2"
	shift
	;;
		-c|--critical)
		CRITICAL_THRESHOLD="$2"
	shift
	;;
		*)
		echo "Unkown argument: Usage ./check_psql_connections.sh -w <warning> -c <critical>"
		exit 1
		;;
	esac
	shift
done

# Abort if OPEN_CONNECTIONS variable doesn't contains a number
if [[ ! $OPEN_CONNECTIONS =~ ^[0-9]+$ ]]; then
    echo "Unable to parse connections from SQL Query"
    exit 3
fi

echo "$OPEN_CONNECTIONS of $MAX_CONNECTIONS in use"

# Check if critical threshold is reached
[[ $OPEN_CONNECTIONS -gt $CRITICAL_THRESHOLD ]] && exit 2

# Check if warning threshold is reached
[[ $OPEN_CONNECTIONS -gt $WARNING_THRESHOLD ]] && exit 1
